#ifndef SVN_VERSION_H
#define SVN_VERSION_H

#define SVN_VERSION "ef335f4614477b53879af8c1a59f3621f80bdd55 [/startdir/boinc] (archlinux:/build/boinc/src/boinc [makepkg]) [Server-Release: server_release/1.x/1.x.0-976-gef335f4614477b53879af8c1a59f3621f80bdd55]"
#define GIT_REVISION 0xef335f46
#define GIT_DATE 1721688928
#define REPOSITORY__STARTDIR_BOINC 1

#endif
